==> hubzero-submit-pegasus_4.5.2-3+deb8.tar.gz: pegasus-4.5.2/share/doc/pegasus/html/braindump_file.php <==
<?php  
            include_once( $_SERVER['DOCUMENT_ROOT']."/static/includes/common.inc.php" );
            do_html_header("Documentation");
        ?><div id="content">
<div class="navheader">
<table width="100%" summary="Navigation header"><tr>
<td width="20%" align="left">
<a accesskey="p" href="jobstate_log_file.php">Prev</a> </td>
<td width="60%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="20%" align="right"> <a accesskey="n" href="static_bp_file.php">Next</a>
</td>
</tr></table>
<hr>
</div>
<div class="section">
<div class="titlepage"><div><div><h2 class="title" style="clear: both">
<a name="braindump_file"></a>13.5. Braindump File</h2></div></div></div>
<p>The braindump file is created per workflow in the submit file and
    contains metadata about the workflow.</p>
<div class="table">
<a name="idp52132480"></a><p class="title"><b>Table 13.2. Table 2: Information Captured in Braindump File</b></p>
<div class="table-contents"><table summary="Table 2: Information Captured in Braindump File" border="1">
<colgroup>
<col>
<col>
</colgroup>
<tbody>
<tr>
<td><span class="bold"><strong>KEY</strong></span></td>
<td><span class="bold"><strong>DESCRIPTION</strong></span></td>
</tr>
<tr>
<td>user</td>
<td>the username of the user that ran pegasus-plan</td>
</tr>
<tr>
<td>grid_dn</td>
<td>the Distinguished Name in the proxy</td>
</tr>
<tr>
<td>submit_hostname</td>
<td>the hostname of the submit host</td>
</tr>
<tr>
<td>root_wf_uuid</td>
<td>the workflow uuid of the root workflow</td>
</tr>
<tr>
<td>wf_uuid</td>
<td>the workflow uuid of the current workflow i.e the one whose
            submit directory the braindump file is.</td>
</tr>
<tr>
<td>dax</td>
<td>the path to the dax file</td>
</tr>
<tr>
<td>dax_label</td>
<td>the label attribute in the adag element of the dax</td>
</tr>
<tr>
<td>dax_index</td>
<td>the index in the dax.</td>
</tr>
<tr>
<td>dax_version</td>
<td>the version of the DAX schema that DAX referred to.</td>
</tr>
<tr>
<td>pegasus_wf_name</td>
<td>the workflow name constructed by pegasus when
            planning</td>
</tr>
<tr>
<td>timestamp</td>
<td>the timestamp when planning occured</td>
</tr>
<tr>
<td>basedir</td>
<td>the base submit directory</td>
</tr>
<tr>
<td>submit_dir</td>
<td>the full path for the submit directory</td>
</tr>
<tr>
<td>properties</td>
<td>the full path to the properties file in the submit
            directory</td>
</tr>
<tr>
<td>planner</td>
<td>the planner used to construct the executable workflow.
            always pegasus</td>
</tr>
<tr>
<td>planner_version</td>
<td>the versions of the planner</td>
</tr>
<tr>
<td>pegasus_build</td>
<td>the build timestamp</td>
</tr>
<tr>
<td>planner_arguments</td>
<td>the arguments with which the planner is invoked.</td>
</tr>
<tr>
<td>jsd</td>
<td>the path to the jobstate file</td>
</tr>
<tr>
<td>rundir</td>
<td>the rundir in the numbering scheme for the submit
            directories</td>
</tr>
<tr>
<td>pegasushome</td>
<td>the root directory of the pegasus installation</td>
</tr>
<tr>
<td>vogroup</td>
<td>the vo group to which the user belongs to. Defaults to
            pegasus</td>
</tr>
<tr>
<td>condor_log</td>
<td>the full path to condor common log in the submit
            directory</td>
</tr>
<tr>
<td>notify</td>
<td>the notify file that contains any notifications that need
            to be sent for the workflow.</td>
</tr>
<tr>
<td>dag</td>
<td>the basename of the dag file created</td>
</tr>
<tr>
<td>type</td>
<td>the type of executable workflow. Can be dag | shell</td>
</tr>
</tbody>
</table></div>
</div>
<br class="table-break"><p>A Sample Braindump File is displayed below:</p>
<pre class="programlisting">user vahi
grid_dn null
submit_hostname obelix
root_wf_uuid a4045eb6-317a-4710-9a73-96a745cb1fe8
wf_uuid a4045eb6-317a-4710-9a73-96a745cb1fe8
dax /data/scratch/vahi/examples/synthetic-scec/Test.dax
dax_label Stampede-Test
dax_index 0
dax_version 3.3
pegasus_wf_name Stampede-Test-0
timestamp 20110726T153746-0700
basedir /data/scratch/vahi/examples/synthetic-scec/dags
submit_dir /data/scratch/vahi/examples/synthetic-scec/dags/vahi/pegasus/Stampede-Test/run0005
properties pegasus.6923599674234553065.properties
planner /data/scratch/vahi/software/install/pegasus/default/bin/pegasus-plan
planner_version 3.1.0cvs
pegasus_build 20110726221240Z
planner_arguments "--conf ./conf/properties --dax Test.dax --sites local --output local --dir dags --force --submit "
jsd jobstate.log
rundir run0005
pegasushome /data/scratch/vahi/software/install/pegasus/default
vogroup pegasus
condor_log Stampede-Test-0.log
notify Stampede-Test-0.notify
dag Stampede-Test-0.dag
type dag
</pre>
</div>
<div class="navfooter">
<hr>
<table width="100%" summary="Navigation footer">
<tr>
<td width="40%" align="left">
<a accesskey="p" href="jobstate_log_file.php">Prev</a> </td>
<td width="20%" align="center"><a accesskey="u" href="submit_directory.php">Up</a></td>
<td width="40%" align="right"> <a accesskey="n" href="static_bp_file.php">Next</a>
</td>
</tr>
<tr>
<td width="40%" align="left" valign="top">13.4. Jobstate.Log File </td>
<td width="20%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="40%" align="right" valign="top"> 13.6. Pegasus static.bp File</td>
</tr>
</table>
</div>
</div><?php  
            do_html_footer();
        ?>

==> hubzero-submit-pegasus_4.5.2-4+deb8.tar.gz: pegasus-4.5.2/share/doc/pegasus/html/braindump_file.php <==
<?php  
            include_once( $_SERVER['DOCUMENT_ROOT']."/static/includes/common.inc.php" );
            do_html_header("Documentation");
        ?><div id="content">
<div class="navheader">
<table width="100%" summary="Navigation header"><tr>
<td width="20%" align="left">
<a accesskey="p" href="jobstate_log_file.php">Prev</a> </td>
<td width="60%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="20%" align="right"> <a accesskey="n" href="static_bp_file.php">Next</a>
</td>
</tr></table>
<hr>
</div>
<div class="section" title="13.5. Braindump File">
<div class="titlepage"><div><div><h2 class="title" style="clear: both">
<a name="braindump_file"></a>13.5. Braindump File</h2></div></div></div>
<p>The braindump file is created per workflow in the submit file and
    contains metadata about the workflow.</p>
<div class="table">
<a name="idp17067568"></a><p class="title"><b>Table 13.2. Table 2: Information Captured in Braindump File</b></p>
<div class="table-contents"><table summary="Table 2: Information Captured in Braindump File" border="1">
<colgroup>
<col>
<col>
</colgroup>
<tbody>
<tr>
<td><span class="bold"><strong>KEY</strong></span></td>
<td><span class="bold"><strong>DESCRIPTION</strong></span></td>
</tr>
<tr>
<td>user</td>
<td>the username of the user that ran pegasus-plan</td>
</tr>
<tr>
<td>grid_dn</td>
<td>the Distinguished Name in the proxy</td>
</tr>
<tr>
<td>submit_hostname</td>
<td>the hostname of the submit host</td>
</tr>
<tr>
<td>root_wf_uuid</td>
<td>the workflow uuid of the root workflow</td>
</tr>
<tr>
<td>wf_uuid</td>
<td>the workflow uuid of the current workflow i.e the one whose
            submit directory the braindump file is.</td>
</tr>
<tr>
<td>dax</td>
<td>the path to the dax file</td>
</tr>
<tr>
<td>dax_label</td>
<td>the label attribute in the adag element of the dax</td>
</tr>
<tr>
<td>dax_index</td>
<td>the index in the dax.</td>
</tr>
<tr>
<td>dax_version</td>
<td>the version of the DAX schema that DAX referred to.</td>
</tr>
<tr>
<td>pegasus_wf_name</td>
<td>the workflow name constructed by pegasus when
            planning</td>
</tr>
<tr>
<td>timestamp</td>
<td>the timestamp when planning occured</td>
</tr>
<tr>
<td>basedir</td>
<td>the base submit directory</td>
</tr>
<tr>
<td>submit_dir</td>
<td>the full path for the submit directory</td>
</tr>
<tr>
<td>properties</td>
<td>the full path to the properties file in the submit
            directory</td>
</tr>
<tr>
<td>planner</td>
<td>the planner used to construct the executable workflow.
            always pegasus</td>
</tr>
<tr>
<td>planner_version</td>
<td>the versions of the planner</td>
</tr>
<tr>
<td>pegasus_build</td>
<td>the build timestamp</td>
</tr>
<tr>
<td>planner_arguments</td>
<td>the arguments with which the planner is invoked.</td>
</tr>
<tr>
<td>jsd</td>
<td>the path to the jobstate file</td>
</tr>
<tr>
<td>rundir</td>
<td>the rundir in the numbering scheme for the submit
            directories</td>
</tr>
<tr>
<td>pegasushome</td>
<td>the root directory of the pegasus installation</td>
</tr>
<tr>
<td>vogroup</td>
<td>the vo group to which the user belongs to. Defaults to
            pegasus</td>
</tr>
<tr>
<td>condor_log</td>
<td>the full path to condor common log in the submit
            directory</td>
</tr>
<tr>
<td>notify</td>
<td>the notify file that contains any notifications that need
            to be sent for the workflow.</td>
</tr>
<tr>
<td>dag</td>
<td>the basename of the dag file created</td>
</tr>
<tr>
<td>type</td>
<td>the type of executable workflow. Can be dag | shell</td>
</tr>
</tbody>
</table></div>
</div>
<br class="table-break"><p>A Sample Braindump File is displayed below:</p>
<pre class="programlisting">user vahi
grid_dn null
submit_hostname obelix
root_wf_uuid a4045eb6-317a-4710-9a73-96a745cb1fe8
wf_uuid a4045eb6-317a-4710-9a73-96a745cb1fe8
dax /data/scratch/vahi/examples/synthetic-scec/Test.dax
dax_label Stampede-Test
dax_index 0
dax_version 3.3
pegasus_wf_name Stampede-Test-0
timestamp 20110726T153746-0700
basedir /data/scratch/vahi/examples/synthetic-scec/dags
submit_dir /data/scratch/vahi/examples/synthetic-scec/dags/vahi/pegasus/Stampede-Test/run0005
properties pegasus.6923599674234553065.properties
planner /data/scratch/vahi/software/install/pegasus/default/bin/pegasus-plan
planner_version 3.1.0cvs
pegasus_build 20110726221240Z
planner_arguments "--conf ./conf/properties --dax Test.dax --sites local --output local --dir dags --force --submit "
jsd jobstate.log
rundir run0005
pegasushome /data/scratch/vahi/software/install/pegasus/default
vogroup pegasus
condor_log Stampede-Test-0.log
notify Stampede-Test-0.notify
dag Stampede-Test-0.dag
type dag
</pre>
</div>
<div class="navfooter">
<hr>
<table width="100%" summary="Navigation footer">
<tr>
<td width="40%" align="left">
<a accesskey="p" href="jobstate_log_file.php">Prev</a> </td>
<td width="20%" align="center"><a accesskey="u" href="submit_directory.php">Up</a></td>
<td width="40%" align="right"> <a accesskey="n" href="static_bp_file.php">Next</a>
</td>
</tr>
<tr>
<td width="40%" align="left" valign="top">13.4. Jobstate.Log File </td>
<td width="20%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="40%" align="right" valign="top"> 13.6. Pegasus static.bp File</td>
</tr>
</table>
</div>
</div><?php  
            do_html_footer();
        ?>
